
%initCobraToolbox(false);

%Load Pseudomonas putida KT2440 model downloaded from  Bigg Models Data Base
ppubigg = readCbModel('pputidabigg.xml');
ppubigg;


% Culture medium conditions
ppu = changeRxnBounds(ppubigg, 'EX_gly_e',-0.1,'l');
ppu = changeRxnBounds(ppu,'EX_succ_e',-0.95,'l');
ppu = changeRxnBounds(ppu,'EX_glc__D_e',-11.7,'l');
ppu = changeRxnBounds(ppu,'EX_cobalt2_e',-0.0375,'l');
ppu = changeRxnBounds(ppu, 'EX_thr__L_e',-0.48,'l');
ppu = changeRxnBounds(ppu,'EX_o2_e',-18.5,'l');

% Optimized yield of Biomass from Bigg's model with culture medium.
%       f: 0.9811 (f expected for Biomass) 
%       f: -3.3661e-13 (f expected for Vit B12) 

bioppu = changeObjective (ppu, 'BIOMASS_KT2440_WT3');
optbioppu = optimizeCbModel(bioppu);
optbioppu; 

%106	Optimized yield of vitamin B12 from Bigg's model with culture medium

vitppu = changeObjective (ppu, 'ADOCBLS');
optvitppu = optimizeCbModel(vitppu);
optvitppu;

%_____________________________________________________________________________________________________________________________________________

%   Curated model of P.putida KT2440. The 3 missing reactions are added:
%   reaction R05224. EC:6.3.5.9 (cobyrinate a,c-diamide synthase), 
% reaction R09083. EC: 1.13.11.79 (aerobic 5,6-dimethyl benzimidazole synthase)
%   and eaction R05217. EC:1.14.13.83 (precorrin-3B synthase)

%           f: 1.8017  (f expected for Biomass) 
%           f: 3.5914e-04 (f expected for Vit B12)

%	Adding reaction R05224. EC:6.3.5.9 (cobyrinate a,c-diamide synthase)
ppuc = addReaction(ppu, 'R05224', 'metaboliteList', {'atp[c]', 'hgbyr[c]','h2o[c]', 'gln__L[c]', 'adp[c]', 'pi[c]', 'hgbam[c]', 'glu__L[c]'}, 'stoichCoeffList',[-2;-1;-2;-2;2;2;1;2]);

%	Adding reaction R09083. EC: 1.13.11.79 (aerobic 5,6-dimethyl benzimidazole synthase)
ppuc = addReaction(ppuc, 'R09083', 'metaboliteList', {'fmnh2[c]', 'o2[c]','dmbzid[c]', 'e4p[c]','h2o[c]'}, 'stoichCoeffList', [-1;-1;1;1;1;]); 

%   Adding reaction R05217. EC:1.14.13.83 (precorrin-3B synthase) ## Verify

ppuc= addReaction(ppuc, 'R05217', 'metaboliteList', {'pre3a[c]', 'nadh[c]', 'h[c]', 'o2[c]', 'pre3b[c]', 'nad[c]', 'h2o[c]'}, 'stoichCoeffList', [-1;-1;-1;-1;1;1;1]);

%   Optimized yield of curated model biomass with the culture medium
bioppuc = changeObjective (ppuc, 'BIOMASS_KT2440_WT3');
optbioppuc = optimizeCbModel(bioppuc);
optbioppuc;

%   Optimized yield of Vitamin B12 from curated model with culture medium.
vitppuc = changeObjective (ppuc, 'ADOCBLS');
optvitppuc = optimizeCbModel(vitppuc);
optvitppuc;

%_____________________________________________________________________________________________________________________________________________

%   Curated model of P.putida KT2440 with aminopropanol linker reactions: L-threonine kinase (EC:2.7.1.177) and  Threonine-phosphate decarboxylase (EC:4.1.1.81)
%           f: 1.8017  (f expected for Biomass) 
%           f:  4.0048e-04 (f expected for Vit B12) 

%   Adding reaction LTHRK EC:2.7.1.177 (L-threonine kinase)
ppuclink = addReaction(ppuc, 'LTHRK', 'metaboliteList', {'thr__L[c]', 'atp[c]', 'adp[c]', 'thrp[c]'}, 'stoichCoeffList', [-1;-1;1;1], 'reversible',false);

%   Adding reaction THRPDC EC:4.1.1.81 (Threonine-phosphate decarboxylase)
ppuclink = addReaction(ppuclink, 'THRPDC', 'metaboliteList', {'thrp[c]', 'co2[c]', 'applp[c]'}, 'stoichCoeffList', [-1; 1; 1], 'reversible',false);

%   Optimized yield of curated model biomass with the culture medium and with aminopropanol linker genes

bioppuclink = changeObjective (ppuclink, 'BIOMASS_KT2440_WT3');
optbioppuclink = optimizeCbModel(bioppuclink);
optbioppuclink;

%   Optimized yield of Vitamin B12 from curated model with culture medium and with aminopropanol linker genes
vitppuclink = changeObjective (ppuclink, 'ADOCBLS');
optvitppuclink = optimizeCbModel(vitppuclink);
optvitppuclink;
%_____________________________________________________________________________________________________________________________________________

%   Curated model of P.putida KT2440 with reaction GLYAT EC: 2.3.1.37 (Ala synthase reaction)
%       Ala synthase reaction (EC: 2.3.1.37)
%           f: 1.8017  (f expected for Biomass) 
%           f: 3.9428e-04  (f expected for Vit B12) 

% Adding reaction GLYAT EC: 2.3.1.37 (Ala synthase reaction)
ppuc37 = addReaction(ppuc, 'GLYAT', 'metaboliteList', {'gly[c]', 'succoa[c]','coa[c]', 'co2[c]', '5aop[c]'}, 'stoichCoeffList', [-1; -1; 1; 1; 1], 'reversible', false);

%   Optimized yield of curated model biomass with the culture medium and with GLYAT reaction EC:2.3.1.37
bioppuc37 = changeObjective (ppuc37, 'BIOMASS_KT2440_WT3');
optbioppuc37 = optimizeCbModel(bioppuc37);
optbioppuc37;

%   Optimized yield of Vitamin B12 from curated model with culture medium and  with GLYAT reaction EC:2.3.1.37
%    f: 3.9428e-04  (f expected for Vit B12) 
vitppuc37 = changeObjective (ppuc37, 'ADOCBLS');
optvitppuc37 = optimizeCbModel(vitppuc37);
optvitppuc37;

%_____________________________________________________________________________________________________________________________________________

%   Curated model of P.putida KT2440. Adding R00371 reaction EC:2.3.1.29  (Glycine C-acetyltransferase)
%       Glycine C-acetyltransferase (EC:2.3.1.29)
%           f: 1.8017  (f expected for Biomass) 
%           f: 1.7995e-04 (f expected for Vit B12)

%       Adding reaction R00371 EC:2.3.1.29 (Glycine C-acetyltransferase)
ppuc29= addReaction(ppuc, 'R00371', 'metaboliteList', {'accoa[c]', 'gly[c]', 'coa[c]','2aobut[c]'}, 'stoichCoeffList', [-1; -1; 1; 1]);

%   Optimized yield of curated model biomass with the culture medium and   with R00371 reaction EC:2.3.1.29 (Glycine C-acetyltransferase)

bioppuc29 = changeObjective (ppuc29, 'BIOMASS_KT2440_WT3');
optbioppuc29 = optimizeCbModel(bioppuc29);
optbioppuc29;

%   Optimized yield of Vitamin B12 from curated model with culture medium  and with R00371 reaction EC:2.3.1.29  (Glycine C-acetyltransferase)

vitppuc29 = changeObjective (ppuc29, 'ADOCBLS');
optvitppuc29 = optimizeCbModel(vitppuc29);
optvitppuc29;

%_____________________________________________________________________________________________________________________________________________

%   Curated model of P.putida KT2440 with R00371 reaction EC:2.3.1.29, and GLYAT reaction EC: 2.3.1.37
%   Glycine C-acetyltransferase (EC: 2.3.1.29) and Ala synthase reaction (EC: 2.3.1.37) 
%           f: 1.8017  (f expected for Biomass) 
%           f: 3.9428e-04  (F expected for Vit B12)

%   Adding GLYAT reaction EC: 2.3.1.37 (Ala synthase) to curated model with Glycine C-acetyltransferase (EC: 2.3.1.29)
ppuc2937 = addReaction(ppuc29, 'GLYAT', 'metaboliteList', {'gly[c]','succoa[c]', 'coa[c]', 'co2[c]', '5aop[c]'}, 'stoichCoeffList', [-1; -1; 1; 1; 1], 'reversible', false);

%   Optimized yield of curated model biomass with the culture medium and with R00371 reaction EC:2.3.1.29, and GLYAT reaction EC: 2.3.1.37
bioppuc2937 = changeObjective (ppuc2937, 'BIOMASS_KT2440_WT3');
optbioppuc2937 = optimizeCbModel(bioppuc2937);
optbioppuc2937;

%   Optimized yield of Vitamin B12 curated model with the culture medium and with R00371 reaction EC:2.3.1.29, and GLYAT reaction EC: 2.3.1.37
vitppuc2937 = changeObjective (ppuc2937, 'ADOCBLS');
optvitppuc2937 = optimizeCbModel(vitppuc2937);
optvitppuc2937;

%_____________________________________________________________________________________________________________________________________________

%   Curated model of P.putida KT2440 with aminopropanol linker genes and GLYAT EC: 2.3.1.37 (Ala synthase reaction)
%       Ala synthase reaction (EC: 2.3.1.37 )
%           f: 1.8017       (f expected for Biomass) 
%           f: 2.1525e-04   (f expected for Vit B12)

%   Adding GLYAT reaction EC: 2.3.1.37 (Ala synthase) to curated model with aminopropanol linker genes
ppuclink37 = addReaction(ppuclink, 'GLYAT', 'metaboliteList', {'gly[c]', 'succoa[c]','coa[c]', 'co2[c]', '5aop[c]'}, 'stoichCoeffList', [-1; -1; 1; 1; 1], 'reversible', false);

%   Optimized yield of curated model biomass with the culture medium and with aminopropanol linker genes GLYAT EC: 2.3.1.37 (Ala synthase reaction)

bioppuclink37 = changeObjective (ppuclink37, 'BIOMASS_KT2440_WT3');
optbioppuclink37 = optimizeCbModel(bioppuclink37);
optbioppuclink37;

%   Optimized yield of Vitamin B12 from curated model with culture medium  and with aminopropanol linker genes and GLYAT EC: 2.3.1.37 (Ala synthase reaction)
vitppuclink37 = changeObjective (ppuclink37, 'ADOCBLS');
optvitppuclink37 = optimizeCbModel(vitppuclink37);
optvitppuclink37;

%_____________________________________________________________________________________________________________________________________________

%   Curated model of P.putida KT2440.Adding R01465 reaction EC: 1.1.1.103
%           f: 1.8017      (f expected for Biomass) 
%           f: 2.2984e-04  (f expected for Vit B12)

%     Adding reaction R00371 EC: 1.1.1.103 (Threonine 3-dehydrogenase)
Ppuc103= addReaction(ppuc, 'R01465', 'metaboliteList', {'thr__L[c]', 'nad[c]', '2aobut[c]', 'nadh[c]', 'h[c]'}, 'stoichCoeffList', [-1; -1; 1; 1; 1]);

%   Optimized yield of curated model biomass with the culture medium and with R01465 reaction EC: 1.1.1.103
bioppuc103 = changeObjective (Ppuc103, 'BIOMASS_KT2440_WT3');
optbioppuc103 = optimizeCbModel(bioppuc103);
optbioppuc103;

%   Optimized yield of Vitamin B12 from curated model with culture medium and with R01465 reaction EC: 1.1.1.103
vitppuc103 = changeObjective (Ppuc103, 'ADOCBLS');
optvitppuc103 = optimizeCbModel(vitppuc103);
optvitppuc103;

%_____________________________________________________________________________________________________________________________________________

%   Curated model of P.putida KT2440. Adding R00371 reaction EC:2.3.1.29 and R01465 reaction EC: 1.1.1.103
%           f: 1.8017      (f expected for Biomass) 
%           f: 3.9083e-04   (f expected for Vit B12)

%   Adding Threonine  3-dehydrogenase reaction (EC: 1.1.1.103) to curated model with Glycine C-acetyltranerase reaction (EC: 2.3.1.29)
ppuc29103= addReaction(ppuc29, 'R01465', 'metaboliteList', {'thr__L[c]', 'nad [c]', '2aobut[c]', 'nadh[c]', 'h[c]'}, 'stoichCoeffList', [-1; -1; 1; 1; 1]);

%   Optimized yield of curated model biomass with the culture medium and  with R00371 reaction EC:2.3.1.29 and R01465 reaction EC: 1.1.1.103

bioppuc29103 = changeObjective (ppuc29103, 'BIOMASS_KT2440_WT3');
optbioppuc29103 = optimizeCbModel(bioppuc29103);
optbioppuc29103;

%	Optimized yield of Vitamin B12 from curated model with the culture medium and with R00371 reaction EC:2.3.1.29. and R01465 reaction EC: 1.1.1.103
vitppuc29103 = changeObjective (ppuc29103, 'ADOCBLS');
optvitppuc29103 = optimizeCbModel(vitppuc29103);
optvitppuc29103;

