%Optgene based algorithm

initCobraToolbox(false);

model = readCbModel('Pputidacurated.mat'); %Loading curated model.

%Establishing medium conditions
model = changeRxnBounds(model, 'EX_gly_e',-0.1,'l');
model = changeRxnBounds(model,'EX_succ_e',-0.95,'l');
model = changeRxnBounds(model,'EX_glc__D_e',-11.7,'l');
model = changeRxnBounds(model,'EX_cobalt2_e',-0.0375,'l');
model = changeRxnBounds(model, 'EX_thr__L_e',-0.48,'l');
model = changeRxnBounds(model,'EX_o2_e',-18.5,'l');

%Adding reactions suggested by the Knockin analysis.
%   Adding reaction LTHRK EC:2.7.1.177 (L-threonine kinase)
model = addReaction(model, 'LTHRK', 'metaboliteList', {'thr__L[c]', 'atp[c]', 'adp[c]', 'thrp[c]'}, 'stoichCoeffList', [-1;-1;1;1], 'reversible',false);

%   Adding reaction THRPDC EC:4.1.1.81 (Threonine-phosphate decarboxylase)
model = addReaction(model, 'THRPDC', 'metaboliteList', {'thrp[c]', 'co2[c]', 'applp[c]'}, 'stoichCoeffList', [-1; 1; 1], 'reversible',false);


% List of reactions to potentially remove. Other reactions from the model can be used as well.
% CPPPGO: (EC:1.3.3.3) , PPPGO: (EC:1.3.3.4) , CPPPGO2: (EC:1.3.98.3 / 1.3.99.22) , UPPDC1: (EC:4.1.1.37) , 
% SHCHF: (EC:4.99.1.4) , FCLT: (EC:4.99.1.1) , GLYCL:(EC:1.4.4.2) , THFAT: (EC:2.1.2.10),
% FOMETRi: (EC:2.1.2.10) , AKGDH: (EC:1.8.1.4/1.2.4.2) , ATHRDHr (EC: 1.1.1.381): , SHCHD2 (EC:1.3.1.76)

rxnsToRemoveList = {'CPPPGO', 'PPPGO', 'CPPPGO2', 'UPPDC1', 'SHCHF', 'FCLT', 'GLYCL', 'THFAT', 'FOMETRi', 'AKGDH', 'ATHRDHr', 'SHCHD2'};  % Example list
max_input = length(rxnsToRemoveList);

% Initialize the input variable
userInput = 0;

% Loop until valid input is received
while true
    % Prompt the user for input
    userInput = input(['Select the maximum number of reaction combinations. Enter a value between 1 and ', num2str(max_input), ': ']);

    % Check if the input is valid
    if isnumeric(userInput) && userInput >= 1 && userInput <= max_input
        disp(['You entered: ', num2str(userInput)]);
        break;  % Exit the loop if input is valid
    else
        disp(['Invalid input. Please enter a number between 1 and ', num2str(max_input), '.']);
    end
end

% Initialize an empty cell array to store the reactions
rxnList = cell(1, userInput);

% Loop to create the reaction names
for i = 1:userInput
    rxnList{i} = ['rxn', num2str(i)];  % Append 'rxn' + i to the list
end

disp(rxnList)

% Store results for each combination
results = {};

%If exists csv delete it and create it again
filename = 'output.csv';
if exist(filename, 'file') == 2
    delete(filename);
end

headers = [rxnList, {'Biomass', 'Vitamin B12'}];
writecell(headers,'output.csv');

%Start timer
tic;

% Loop for combinations of 1, 2, 3 to the number of elements choose by user.
for k = 1:userInput
    combinations = nchoosek(rxnsToRemoveList, k);  % Get combinations of k reactions
    numCombinations = size(combinations, 1);
    
    for i = 1:numCombinations
        % Get the current combination of reactions to remove
        rxnsToRemove = combinations(i, :);
       
        % Create a copy of the model to remove reactions from
        modelknock = removeRxns(model,rxnsToRemove); 

        %Calculate Biomass function of the model with the Knockout(s) tested
        biomodel = changeObjective (modelknock, 'BIOMASS_KT2440_WT3');
        optbiomodel = optimizeCbModel(biomodel);
        
        %Calculate Vitamin B12 function of the model with the Knockout(s) tested
        vitmodel = changeObjective (modelknock, 'ADOCBLS');
        optvitmodel = optimizeCbModel(vitmodel);
        %Modify the length for printing purposes
        rxnsToRemove=[rxnsToRemove,repmat({''},1,userInput-k)];
        KnockList = [rxnsToRemove, optbiomodel.f,optvitmodel.f];
        writecell(KnockList,"output.csv",'WriteMode','append');
    end
end

elapsedTime = toc;
fprintf('Analysis duration time: %.2f seconds\n', elapsedTime);